DomainRef

Struct DomainRef 

pub struct DomainRef<'a> { /* private fields */ }
A Domain reference.

Implementations

Source

impl<'a> DomainRef<'a>

Special Domains

pub const LOCALHOST: Self

The localhost domain.

pub const EXAMPLE: Self

The example.com domain.

Source

impl<'a> DomainRef<'a>

Construction

pub unsafe fn new_unchecked(name: &'a str) -> Self

Creates a new DomainRef.

Safety

The name must be valid and lowercase.

Source

impl<'a> DomainRef<'a>

Properties

pub const fn name(self) -> &'a str

Gets the name.

Source

impl<'a> DomainRef<'a>

Labels

pub const fn labels(self) -> Labels<'a>

Gets the labels.

Source

impl<'a> DomainRef<'a>

Conversions

pub fn to_domain(self) -> Domain

Converts the domain reference to a domain.

pub fn to_endpoint(self, port: u16) -> Endpoint

Converts the domain reference to an endpoint with the port.

pub const fn to_endpoint_ref(self, port: u16) -> EndpointRef<'a>

Converts the domain reference to an endpoint reference with the port.

pub fn to_host(self) -> Host

Converts the domain reference to a host.

pub const fn to_host_ref(self) -> HostRef<'a>

Converts the domain reference to a host reference.

Source

impl<'a> DomainRef<'a>

Parse

pub fn parse_text(text: &'a [u8]) -> Result<Self, ParseError>

Dot-separated labels of ASCII letters, digits, & dashes. (see Domain::is_valid_name) The name must already be in lowercase. Use Domain to parse mixed-case input.

Source

impl<'a> DomainRef<'a>

International Domain Names

pub fn to_unicode(self) -> Result<String, ParseError>

Available on crate feature idna only.

Converts the domain name to its Unicode representation.

Returns an error if a label contains invalid punycode. (example: xn--a.example)