pub struct DomainRef<'a> { /* private fields */ }Expand description
A Domain reference.
Implementations
Sourceimpl<'a> DomainRef<'a>
Conversions
impl<'a> DomainRef<'a>
Conversions
Sourcepub fn to_endpoint(self, port: u16) -> Endpoint
pub fn to_endpoint(self, port: u16) -> Endpoint
Converts the domain reference to an endpoint with the port.
Sourcepub const fn to_endpoint_ref(self, port: u16) -> EndpointRef<'a>
pub const fn to_endpoint_ref(self, port: u16) -> EndpointRef<'a>
Converts the domain reference to an endpoint reference with the port.
Sourcepub const fn to_host_ref(self) -> HostRef<'a>
pub const fn to_host_ref(self) -> HostRef<'a>
Converts the domain reference to a host reference.
Sourceimpl<'a> DomainRef<'a>
Parse
impl<'a> DomainRef<'a>
Parse
Sourcepub fn parse_text(text: &'a [u8]) -> Result<Self, ParseError>
pub fn parse_text(text: &'a [u8]) -> Result<Self, ParseError>
Dot-separated labels of ASCII letters, digits, & dashes. (see Domain::is_valid_name)
The name must already be in lowercase. Use Domain to parse mixed-case input.
Sourceimpl<'a> DomainRef<'a>
International Domain Names
impl<'a> DomainRef<'a>
International Domain Names
Sourcepub fn to_unicode(self) -> Result<String, ParseError>
Available on crate feature idna only.
pub fn to_unicode(self) -> Result<String, ParseError>
idna only.Converts the domain name to its Unicode representation.
Returns an error if a label contains invalid punycode. (example: xn--a.example)